# Copyright (c) 2022, NVIDIA CORPORATION.  All Rights Reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.
#

from tkinter import StringVar
from tkinter.ttk import Label, LabelFrame

from ...utils.common import PAttrs, PNames
from ...utils.layoutmanager import fill_parent, grid_span, padding
from ...utils.subjectobserver import Observer

class CPUFrame(LabelFrame, Observer):
    def __init__(self, master=None, **kwargs):
        self.cpu_nums = kwargs["cpu_nums"]
        kwargs.pop("cpu_nums")
        super().__init__(master, text="CPU", **kwargs)
        self.create_widgets()
        self.manage_layout()
        fill_parent(self)

    def create_widgets(self):
        self.freq_v = [None] * self.cpu_nums
        self.load_v = [None] * self.cpu_nums
        self.cpu_l = [None] * self.cpu_nums
        self.freq_l = [None] * self.cpu_nums
        self.load_l = [None] * self.cpu_nums
        self.name_hl = Label(self, text="Name")
        self.freq_hl = Label(self, text="Freq (MHz)")
        self.load_hl = Label(self, text="Load %")

        for i in range(self.cpu_nums):
            self.freq_v[i] = StringVar()
            self.load_v[i] = StringVar()
            self.cpu_l[i] = Label(self, text=f"cpu{i}")
            self.freq_l[i] = Label(self, textvariable=self.freq_v[i])
            self.load_l[i] = Label(self, textvariable=self.load_v[i])

    def manage_layout(self):
        self.name_hl.grid(row=0, column=0, **grid_span, **padding)
        self.freq_hl.grid(row=0, column=1, **grid_span, **padding)
        self.load_hl.grid(row=0, column=2, **grid_span, **padding)

        for i in range(self.cpu_nums):
            self.cpu_l[i].grid(row=1 + i, column=0, **grid_span, **padding)
            self.freq_l[i].grid(row=1 + i, column=1, **grid_span, **padding)
            self.load_l[i].grid(row=1 + i, column=2, **grid_span, **padding)

    def update_data(self, data):
        for i in range(self.cpu_nums):
            cpu_name = f"{PNames.CPU}{i}"
            if data[(cpu_name, PAttrs.STATE)]:
                self.freq_v[i].set(f"{data[(cpu_name, PAttrs.CURR_FREQ)]} MHz")
                self.load_v[i].set(f"{data[(cpu_name, PAttrs.CURR_LOAD)]} %")
            else:
                self.freq_v[i].set("offline")
                self.load_v[i].set("offline")