# Copyright (c) 2022, NVIDIA CORPORATION.  All Rights Reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.
#

from tkinter import StringVar
from tkinter.ttk import Label, LabelFrame

from ...utils.common import PAttrs, PNames
from ...utils.layoutmanager import fill_parent, grid_span, padding
from ...utils.subjectobserver import Observer

class FanFrame(LabelFrame, Observer):
    def __init__(self, master=None, **kwargs):
        self.fan_id = kwargs["fan_id"]
        kwargs.pop("fan_id")
        super().__init__(master, text=f"Fan{self.fan_id}", **kwargs)
        self.create_widgets()
        self.manage_layout()
        fill_parent(self)

    def create_widgets(self):
        self.temp_ctrl_v = StringVar()
        self.pwm_v = StringVar()
        self.tach_enable_v = StringVar()
        self.rpm_v = StringVar()
        self.pwm_hl = Label(self, text="PWM")
        self.tach_hl = Label(self, text="Tach")
        self.temp_ctrl_l = Label(self, textvariable=self.temp_ctrl_v)
        self.tach_enable_l = Label(self, textvariable=self.tach_enable_v)
        self.pwm_l = Label(self, textvariable=self.pwm_v)
        self.tach_l = Label(self, textvariable=self.rpm_v)

    def manage_layout(self):
        self.pwm_hl.grid(row=0, column=0, **grid_span, **padding)
        self.tach_hl.grid(row=1, column=0, **grid_span, **padding)
        self.temp_ctrl_l.grid(row=0, column=1, **grid_span, **padding)
        self.tach_enable_l.grid(row=1, column=1, **grid_span, **padding)
        self.pwm_l.grid(row=0, column=2, **grid_span, **padding)
        self.tach_l.grid(row=1, column=2, **grid_span, **padding)

    def update_data(self, data):
        fan_name = PNames.FAN_NAMES[self.fan_id - 1]
        self.temp_ctrl_v.set("-")
        self.tach_enable_v.set("-")
        self.pwm_v.set(f"{data[(fan_name, PAttrs.CURR_PWM)]} pwm")
        self.rpm_v.set(f"{data[(fan_name, PAttrs.RPM_MEASURED)]} rpm")